<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// E
	'explication_url_statique_ressources' => 'URL, який може обслуговувати статичні файли (зображення, JS ...) без файлів cookie. Зазвичай альтернативний піддомен, який також вказує на сайт.',

	// I
	'info_compresseur_titre' => 'Оптимізація і стискання коду',
	'info_question_activer_compactage_css' => 'Стискання CSS:',
	'info_question_activer_compactage_js' => 'Стискання Javascript:',
	'item_compresseur_css' => 'Стискувати файлы CSS',
	'item_compresseur_js' => 'Стискувати javascript',

	// L
	'label_url_statique_ressources' => 'URL ресурси',

	// T
	'texte_compacter_avertissement' => 'Увага! Коли увімкнено стискання css та javascript файлів дуже важким стає відлажування вихідного коду. Використовуйте ці налаштування після закінчення робіт по створенню сайту.',
	'texte_compacter_script_css' => 'Для прискорення завантаження сайту SPIP може об’єднувати і стискати (мінімізувати) Javascript та CSS файли.',
	'titre_compacter_script_css' => 'Стискання javascript и CSS'
);
